@@ -19,7 +19,7 @@ from aind_mri_targeting.implant_rotations import fit_implant_to_mri_from_files
 
 # %%
 # Paths
-mouse_id = 750108
+mouse_id = 771433
 whoami = "yoni"
 if whoami == "galen":
     scratchdir = Path("/mnt/aind1-vast/scratch/")
@@ -28,18 +28,18 @@ elif whoami == "yoni":
     scratchdir = Path(r"Y:")
 mri_folder = scratchdir / "ephys/persist/data/MRI"
 processed_folder = mri_folder / "processed"
-mouse_folder = processed_folder / str(mouse_id) / 'UW_2024_12_17'
+mouse_folder = processed_folder / str(mouse_id)
 
 # required files
 implant_annotations_file = mouse_folder / f"{mouse_id}_ImplantHoles.seg.nrrd"
 hole_folder = mri_folder / "HeadframeModels/HoleOBJs"
-save_name = str(mouse_folder / f"{mouse_id}_implant_fit.h5")
+save_name = str(mouse_folder)  # f"{mouse_id}_implant_fit.h5")
 
 # optional flags
 save_inverse = (
     True  # save the inverse transformation matrix, which works on volumes
 )
-force = False
+force = True
 
 # %%
 # Run the fitting
@@ -49,10 +49,10 @@ fit_implant_to_mri_from_files(
     save_name=save_name,
     save_inverse=save_inverse,
     force=force,
-    mouse_id=mouse_id,
+    mouse_name=mouse_id,
 )
 
 # %%
-Path(save_name).suffix
+save_name
 
 # %%
