@@ -5,15 +5,15 @@ from aind_mri_targeting.headframe_rotations import headframe_centers_of_mass
 
 # %%
 # Input files
-basepath = Path(r'Y:\ephys\persist\data\MRI\processed\750108\UW_2024_12_17') #Path("/path/to/data")
-mri_path = basepath / '750108_100.nii.gz'#"mri.nii.gz"
-seg_path = basepath / '750108_HeadframeHoles.seg.nrrd'#"segmentation.seg.nrrd"
+basepath = Path(r"Y:\ephys\persist\data\MRI\processed\771433")
+mri_path = basepath / "771433_100.nii.gz"
+seg_path = basepath / "771433_HeadframeHoles.seg.nrrd"
 
 # Output directory
-output_dir = basepath#"/path/to/output"
+output_dir = basepath
 
 # Optional mouse ID
-mouse_id = 750108
+mouse_id = 771433
 
 # Whether to ovewrite:
 force = False
@@ -31,8 +31,10 @@ headframe_centers_of_mass(
     output_dir,
     mouse_id=mouse_id,
     segment_format=segment_format,
-    force=True,
+    force=force,
     ignore_list=ignore_list,
 )
 
 # %%
+
+# %%
