@@ -15,9 +15,9 @@ from aind_mri_utils.chemical_shift import (
     chemical_shift_transform,
     compute_chemical_shift,
 )
-from aind_mri_utils.file_io import simpleitk as mr_sitk
 from aind_mri_utils.file_io import slicer_files as sf
 from aind_mri_utils.file_io.obj_files import get_vertices_and_faces
+from aind_mri_utils.file_io.simpleitk import load_sitk_transform
 from aind_mri_utils.meshes import (
     apply_transform_to_trimesh,
     load_newscale_trimesh,
@@ -31,13 +31,13 @@ from aind_mri_utils.planning import (
 from aind_mri_utils.reticle_calibrations import (
     fit_rotation_params,
     read_reticle_calibration,
-    transform_probe_to_reticle,
+    transform_probe_to_bregma,
 )
 
 # %%
-mouse = "728537"
-vaseline_ppm = 3.67  # (3.7 + 4.1) / 2 for previouse
-whoami = "galen"
+mouse = "765860"
+vaseline_ppm = 3.67  # (3.7 + 4.1) / 2 for previous
+whoami = "yoni"
 if whoami == "galen":
     base_dir = Path("/mnt/aind1-vast/scratch/")
     base_save_dir = Path("/home/galen.lynch/")
@@ -53,16 +53,13 @@ headframe_model_dir = base_dir / "ephys/persist/data/MRI/HeadframeModels/"
 probe_model_file = (
     headframe_model_dir / "dovetailtweezer_oneShank_centered_corrected.obj"
 )  # "modified_probe_holder.obj"
-annotations_path = base_dir / "ephys/persist/data/MRI/processed/{}/UW".format(
-    mouse
+annotations_path = (
+    base_dir / "ephys/persist/data/MRI/processed/{}/UW_2025".format(mouse)
 )
 
 hole_folder = headframe_model_dir / "HoleOBJs"
 implant_model_path = headframe_model_dir / "0283-300-04.obj"
-implant_transform = (
-    annotations_path
-    / f"{mouse}_implant_annotations_to_lps_implant_model_with_brain_better_normalization.h5"  # noqa E501
-)
+implant_transform = annotations_path / f"{mouse}_implant_fit.h5"  # noqa E501
 
 headframe_path = headframe_model_dir / "TenRunHeadframe.obj"
 holes_path = headframe_model_dir / "OneOff_HolesOnly.obj"
@@ -81,17 +78,18 @@ labels_path = str(
 brain_mask_path = str(
     annotations_path / ("{}_auto_skull_strip.nrrd".format(mouse))
 )
-manual_annotation_path = str(
-    annotations_path / (f"{mouse}_ManualAnnotations.fcsv")
+
+template_annotation_path = str(
+    annotations_path / ("fiducials-{}-transformed.fcsv".format(mouse))
 )
 cone_path = (
     base_dir
     / "ephys/persist/Software/PinpointBuilds/WavefrontFiles/Cone_0160-200-53.obj"  # noqa E501
 )
 
-uw_yoni_annotation_path = (
-    annotations_path / f"targets-{mouse}-transformed.fcsv"
-)
+# uw_yoni_annotation_path = (
+#     annotations_path / "fiducials-{}-transformed.fcsv".format(mouse)
+# )
 
 newscale_file_name = headframe_path / "Centered_Newscale_2pt0.obj"
 #
@@ -100,9 +98,8 @@ newscale_file_name = headframe_path / "Centered_Newscale_2pt0.obj"
 calibration_dir = (
     base_dir / "ephys/persist/data/probe_calibrations/CSVCalibrations/"
 )
-measured_hole_centers = (
-    annotations_path / f"{mouse}_measured_hole_centers.xlsx"
-)
+measured_hole_centers = None
+# (  annotations_path / f"{mouse}_measured_hole_centers.xlsx"  )
 
 
 # manual_hole_centers_file = annotations_path / 'hole_centers.mrk.json'
@@ -113,7 +110,7 @@ transformed_targets_save_path = annotations_path / (
 test_probe_translation_save_path = str(
     base_save_dir / "test_probe_translation.h5"
 )
-transform_filename = str(annotations_path / (mouse + "_com_plane.h5"))
+transform_filename = str(annotations_path / ("com_plane.h5"))
 
 # %%
 target_structures = None  # ["CCant", "CCpst", "AntComMid", "GenFacCran2"]
@@ -121,7 +118,7 @@ target_structures = None  # ["CCant", "CCpst", "AntComMid", "GenFacCran2"]
 # %%
 image = sitk.ReadImage(image_path)
 # Read points
-manual_annotation = sf.read_slicer_fcsv(manual_annotation_path)
+template_annotation = sf.read_slicer_fcsv(template_annotation_path)
 
 # Load the headframe
 headframe, headframe_faces = get_vertices_and_faces(headframe_path)
@@ -135,9 +132,9 @@ implant_lps = cs.convert_coordinate_system(
 )  # Preserves shape!
 
 # Load the computed transform
-trans = mr_sitk.load_sitk_transform(
-    transform_filename, homogeneous=True, invert=True
-)[0]
+trans = load_sitk_transform(transform_filename, homogeneous=True, invert=True)[
+    0
+]
 
 cone = trimesh.load_mesh(cone_path)
 cone.vertices = cs.convert_coordinate_system(cone.vertices, "ASR", "LPS")
@@ -152,8 +149,8 @@ chem_shift_trans = chemical_shift_transform(chem_shift, readout="HF")
 
 # List targeted locations
 if target_structures is None:
-    target_structures = list(manual_annotation.keys())
-preferred_pts = {k: manual_annotation[k] for k in target_structures}
+    target_structures = list(template_annotation.keys())
+preferred_pts = {k: template_annotation[k] for k in target_structures}
 
 hmg_pts = rot.prepare_data_for_homogeneous_transform(
     np.array(tuple(preferred_pts.values()))
@@ -194,17 +191,19 @@ for ii, hole_id in enumerate(hole_dict.keys()):
 
 
 # %%
-implant_model_trans = mr_sitk.load_sitk_transform(
-    implant_transform, homogeneous=True, invert=False
-)[0].T
+# This is stored as inverse for the sake of slicer, and must be re-inverted
+# to be used in python
+implant_model_trans = load_sitk_transform(
+    implant_transform, homogeneous=True, invert=True
+)[0]
 
 
 # %%
-implant_names = [*model_implant_targets]
+implant_names = list(model_implant_targets.keys())
 model_targets = np.vstack(list(model_implant_targets.values()))
 implant_targets = (
     rot.prepare_data_for_homogeneous_transform(model_targets)
-    @ implant_model_trans
+    @ implant_model_trans.T
 )
 transformed_implant = rot.extract_data_for_homogeneous_transform(
     implant_targets @ trans.T
@@ -276,7 +275,7 @@ if measured_hole_centers:
         thisprobe = row["Probe"]
         used_scaling = row["Scaling used?"] == "yes"
         fit_type = "scaling" if used_scaling else "no_scaling"
-        hole_measures_ras[hole_num] = transform_probe_to_reticle(
+        hole_measures_ras[hole_num] = transform_probe_to_bregma(
             probe_pt,
             transforms[calfile][thisprobe][fit_type]["rotation"],
             transforms[calfile][thisprobe][fit_type]["offset"],
@@ -294,7 +293,7 @@ for i, n in enumerate(target_names):
             d: transformed_annotation_ras[i, j]
             for j, d in enumerate(dim_names)
         },
-        "point source": "manual",
+        "point source": "Fiducial From Template",
     }
     annotation_data.append(target)
 
@@ -331,7 +330,7 @@ df = candidate_insertions(
     implant_names_sorted,
 )
 compat_matrix = compatible_insertion_pairs(df)
-
+df.to_csv(annotations_path / f"{mouse}_candidate_insertions.csv")
 
 # %%
 df[df.target == "GPe_anterior"]
